import React, { useState } from 'react';
import styles from './Question.module.scss';

import TouchOpacity from 'components/TouchOpacity';

import IconPlay from 'assets/img/play.png';
import IconPlayDefault from 'assets/img/play_default.png';
import IconPause from 'assets/img/pause.png';
import IconCheckBlue from 'assets/img/check-square-blue.png';
import IconCheckDefaultBlue from 'assets/img/check_default-square-blue.png';
import IconCheckRed from 'assets/img/check-square-red.png';
import IconCheckDefaultRed from 'assets/img/check_default-square-red.png';

// question不一定都是问题，也可能是答案，其实分为需要读/不需要读 和 需要操作/不需要操作
export default function(props) {
  const { question, setPlayStatus, setChecked, voiceStart, voicePause, voiceContinue } = props;
  const { questionId, needPlay, needCheck, text, voice, playStatus, checked } = question;

  // 0 未开始-无图标；1 播放中-显示暂停图标；2 暂停中-显示播放图标； 3 已结束-显示灰色播放图标
  // const [playStatus, setPlayStatus] = useState('0');
  // const [checked, setChecked] = useState(false);

  const getPlayIcon = () => {
    if (playStatus === '3') {
      return IconPlayDefault;
    } else if (playStatus === '2') {
      return IconPlay;
    } else if (playStatus === '1') {
      return IconPause;
    }
    return null;
  };

  const getCheckIcon = () => {
    if (needCheck && checked) {
      return IconCheckRed;
    } else if (needCheck && !checked) {
      return IconCheckDefaultRed;
    } else if (!needCheck && checked) {
      return IconCheckBlue;
    } else if (!needCheck && !checked) {
      return IconCheckDefaultBlue;
    }
    return IconCheckBlue;
  };

  const playOrPause = () => {
    console.log({ question });
    if (playStatus === '2') {
      setPlayStatus(questionId, '1');
      // voiceStart(voice);
      voiceContinue();
    } else if (playStatus === '1') {
      setPlayStatus(questionId, '2');
      voicePause();
    }
  };

  const clickChecked = () => {
    if (!needCheck) {
      return;
    }
    setChecked(questionId, !checked);
  };

  return (
    <div className={styles.stepQuestionItem}>
      <TouchOpacity onClick={playOrPause}>
        <img
          src={getPlayIcon()}
          alt="play"
          className={needPlay && playStatus !== '0' ? styles.leftIcon : styles.hide}
        ></img>
      </TouchOpacity>
      <div className={styles.itemText}>{text}</div>
      <TouchOpacity onClick={clickChecked}>
        <img src={getCheckIcon()} alt="check" className={styles.rightIcon}></img>
      </TouchOpacity>
    </div>
  );
}
