import React, { useState } from 'react';
import { Spin } from 'antd';

import styles from './ProductListModal.module.scss';
import TouchOpacity from '../../components/TouchOpacity';
import iconCheck from '../../assets/img/check.png';

const productList = [
  {
    id: '1',
    name: '(MCI34)附加全佑无忧B款重大疾病保险'
  },
  {
    id: '2',
    name: '(M34)附加全佑无忧B款重大疾病保险'
  },
  {
    id: '3',
    name: '(MCR8304)附加多重保障'
  },
  {
    id: '4',
    name: '(EDNT2384)附加十年期定期寿险'
  },
  {
    id: '5',
    name: '(DSIO344)附加全佑无忧B款重大疾病保险'
  },
  {
    id: '6',
    name: '(SADF934)附加全佑无忧B款重大疾病保险'
  },
  {
    id: '7',
    name: '(SF34)附加十年期定期寿险'
  },
  {
    id: '8',
    name: '(DEW34)附加百倍安欣定期寿险'
  },
  {
    id: '9',
    name: '(GEB45)附加十年期定期寿险'
  },
  {
    id: '10',
    name: '(SFOK345)附加全佑无忧B款重大疾病保险'
  },
  {
    id: '11',
    name: '(PLNV834)附加全佑无忧B款重大疾病保险'
  },
  {
    id: '12',
    name: '(KIJD9933)附加百倍安欣定期寿险'
  },
  {
    id: '13',
    name: '(MJJE23)附加全佑无忧B款重大疾病保险'
  },
  {
    id: '14',
    name: '(VNBE345)附加百倍安欣定期寿险'
  },
  {
    id: '15',
    name: '(RFJI34)附加十年期定期寿险'
  },
  {
    id: '16',
    name: '(PEFO0394)附加百倍安欣定期寿险'
  },
  {
    id: '17',
    name: '(FRJ495)附加全佑无忧B款重大疾病保险'
  }
];

export default function(props) {
  const { visible, addTableData, close } = props;
  const [productId, setProductId] = useState('');
  const [loadingVisible, toggleLoadingVisible] = useState(false);

  const clickMain = (event) => {
    // 点击主体的时候禁止冒泡，不关闭modal
    event.stopPropagation();
  };

  const clickItem = (id) => {
    if (productId === id) {
      setProductId('');
    } else {
      toggleLoadingVisible(true);
      setTimeout(() => {
        setProductId(id);
        toggleLoadingVisible(false);
      }, Math.random() * 1000);
    }
  };

  const submit = () => {
    const selectedProduct = productList.find((p) => p.id === productId);
    if (selectedProduct) {
      addTableData(selectedProduct);
    }
    close();
  };

  if (!visible) {
    return <div></div>;
  }
  return (
    <div className={styles.mask} onClick={close}>
      <div className={styles.main} onClick={clickMain}>
        <div className={styles.title}>附加合同选择</div>
        <div className={styles.content}>
          <div className={styles.info}>
            <span>被保险人出生日期：1974年08月07日</span>
            <span>请谨慎选择以下产品的成人或儿童计划</span>
            <TouchOpacity className={styles.btn}>重置</TouchOpacity>
          </div>
          <div className={styles.list}>
            {productList.map((ele) => (
              <TouchOpacity
                key={ele.id}
                className={productId === ele.id ? styles.itemSelect : styles.item}
                onClick={() => {
                  clickItem(ele.id);
                }}
              >
                <span>{ele.name}</span>
                <img src={iconCheck} alt="checkimg" />
              </TouchOpacity>
            ))}
          </div>
          <div className={styles.footer}>
            <TouchOpacity className={styles.btnCancel}>取消</TouchOpacity>
            <TouchOpacity className={styles.btn} onClick={submit}>
              确定
            </TouchOpacity>
          </div>
        </div>
      </div>
      {loadingVisible && (
        <div className={styles.loading}>
          <Spin tip="Loading..."></Spin>
        </div>
      )}
    </div>
  );
}
